==> v1.0.2.1016.tar.gz: athena-opt-demo/demo-athenaopt_backend/develop/src/main/java/com/digiwin/athena/app/ptc/service/receivables/ReceivablesTaskGetEAIService.java <==
package com.digiwin.athena.app.ptc.service.receivables;

import com.alibaba.fastjson.TypeReference;
import com.alibaba.nacos.common.utils.StringUtils;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.digiwin.app.container.exceptions.DWBusinessException;
import com.digiwin.app.service.DWEAIResult;
import com.digiwin.athena.app.infra.common.enums.TabStatusEnums;
import com.digiwin.athena.app.ptc.infra.entity.CollectionDetailEntity;
import com.digiwin.athena.app.ptc.infra.service.CollectionDetailService;
import com.digiwin.athena.opt.common.eai.EAIRequest;
import com.digiwin.athena.opt.common.eai.service.AbsEAIService;
import com.digiwin.athena.opt.common.security.SecurityUtil;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @auther: zhenggl
 * @date: 2023/9/12
 */
@Service
@Log4j2
public class ReceivablesTaskGetEAIService extends AbsEAIService {

    @Resource
    private CollectionDetailService collectionDetailService;

    @Override
    public String getServiceName() {
        return ReceivablesUtil.RECEIVABLES_TASK_GET;
    }

    @Override
    public DWEAIResult execute(Map<String, String> headers, String messageBody) throws Exception {

        EAIRequest eaiRequest = EAIRequest.build(messageBody);
        List<CollectionDetailEntity> collectionDetailEntities = eaiRequest.getObject("get_data", new TypeReference<List<CollectionDetailEntity>>() {});

        for (CollectionDetailEntity collectionDetailEntity : collectionDetailEntities) {
            if (StringUtils.isEmpty(collectionDetailEntity.getSalesOrder())||StringUtils.isEmpty(collectionDetailEntity.getSalesOrderNumber())){
                throw new DWBusinessException("缺少必要参数");
            }
        }

        LambdaQueryWrapper<CollectionDetailEntity> lmq = new LambdaQueryWrapper<>();
        lmq.eq(CollectionDetailEntity::getStatus, TabStatusEnums.PENDING.getValue());
        lmq.eq(CollectionDetailEntity::getTenantSid, SecurityUtil.getUserProfile().getTenantSid());
        lmq.and(queryWrapperInner -> {
            for (CollectionDetailEntity collectionDetailEntity : collectionDetailEntities) {
                queryWrapperInner.or(
                        wrapper -> wrapper
                                .eq(CollectionDetailEntity::getSalesOrder, collectionDetailEntity.getSalesOrder())
                                .eq(CollectionDetailEntity::getSalesOrderNumber, collectionDetailEntity.getSalesOrderNumber())
                );
            }

        });

        List<CollectionDetailEntity> list = collectionDetailService.list(lmq);
        return buildOK("query_result",list);
    }
}

==> v1.0.2.1030.tar.gz: athena-opt-demo/demo-athenaopt_backend/develop/src/main/java/com/digiwin/athena/app/ptc/service/receivables/ReceivablesTaskGetEAIService.java <==
package com.digiwin.athena.app.ptc.service.receivables;

import com.alibaba.fastjson.TypeReference;
import com.alibaba.nacos.common.utils.StringUtils;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.digiwin.app.container.exceptions.DWBusinessException;
import com.digiwin.app.service.DWEAIResult;
import com.digiwin.athena.app.infra.common.enums.TabStatusEnums;
import com.digiwin.athena.app.ptc.infra.entity.CollectionDetailEntity;
import com.digiwin.athena.app.ptc.infra.service.CollectionDetailService;
import com.digiwin.athena.opt.common.eai.EAIRequest;
import com.digiwin.athena.opt.common.eai.service.AbsEAIService;
import com.digiwin.athena.opt.common.security.SecurityUtil;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @auther: zhenggl
 * @date: 2023/9/12
 */
@Service
@Log4j2
public class ReceivablesTaskGetEAIService extends AbsEAIService {

    @Resource
    private CollectionDetailService collectionDetailService;

    @Override
    public String getServiceName() {
        return ReceivablesUtil.RECEIVABLES_TASK_GET;
    }

    @Override
    public DWEAIResult execute(Map<String, String> headers, String messageBody) throws Exception {

        EAIRequest eaiRequest = EAIRequest.build(messageBody);
        List<CollectionDetailEntity> collectionDetailEntities = eaiRequest.getObject("get_data", new TypeReference<List<CollectionDetailEntity>>() {});

        for (CollectionDetailEntity collectionDetailEntity : collectionDetailEntities) {
            if (StringUtils.isEmpty(collectionDetailEntity.getSalesOrder())
                    ||StringUtils.isEmpty(collectionDetailEntity.getSalesOrderNumber())){
                throw new DWBusinessException("缺少必要参数");
            }
        }

        LambdaQueryWrapper<CollectionDetailEntity> lmq = new LambdaQueryWrapper<>();
        lmq.eq(CollectionDetailEntity::getStatus, TabStatusEnums.PENDING.getValue());
        lmq.eq(CollectionDetailEntity::getTenantSid, SecurityUtil.getUserProfile().getTenantSid());
        lmq.and(queryWrapperInner -> {
            for (CollectionDetailEntity collectionDetailEntity : collectionDetailEntities) {
                queryWrapperInner.or(
                        wrapper -> wrapper
                                .eq(CollectionDetailEntity::getSalesOrder, collectionDetailEntity.getSalesOrder())
                                .eq(CollectionDetailEntity::getSalesOrderNumber, collectionDetailEntity.getSalesOrderNumber())
                );
            }

        });

        List<CollectionDetailEntity> list = collectionDetailService.list(lmq);
        return buildOK("query_result",list);
    }
}
